@@ -67,7 +67,7 @@ class CIDClient:
         """
         return f"""
            query {{
-              findByArtifact(artifact: "{artifact}") {{
+              findByArtifact(artifact: {json.dumps(artifact)}) {{
                 total
                 results
               }}
@@ -210,6 +210,13 @@ class CIDClient:
         else:
             raise Exception(data['data']['authenticate']['errorMessage'])
 
+    def custom_asdict_factory(self, data):
+        def convert_value(obj):
+            if isinstance(obj, Enum):
+                return obj.value
+            return obj
+        return dict((k, convert_value(v)) for k, v in data)
+
     def assign_identifier(self, assign_id_input):
         """
         Assign a related CID, DOI, ARK or MARC identifier.
@@ -366,7 +373,7 @@ class CIDClient:
                 },
             ],
             "features": extract_artifacts_input.features,
-            "callback": asdict(extract_artifacts_input.callback)
+            "callback": asdict(extract_artifacts_input.callback, dict_factory=self.custom_asdict_factory)
         }
 
         response = requests.post(
